;; Generated package description from gpr-query.el  -*- no-byte-compile: t -*-
(define-package "gpr-query" "1.0.1.0.20221221.80150" "Minor mode for navigating sources using gpr_query" '((emacs "25.3") (wisi "4.1") (gnat-compiler "1.0")) :commit "89e32005c00be42e9dfabd3a44cadbbdf198b072" :url "https://elpa.gnu.org/packages/gpr-query.html" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org"))
